# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import MELODIC


def test_MELODIC_inputs():
    input_map = dict(
        ICs=dict(argstr="--ICs=%s", extensions=None,),
        approach=dict(argstr="-a %s",),
        args=dict(argstr="%s",),
        bg_image=dict(argstr="--bgimage=%s", extensions=None,),
        bg_threshold=dict(argstr="--bgthreshold=%f",),
        cov_weight=dict(argstr="--covarweight=%f",),
        dim=dict(argstr="-d %d",),
        dim_est=dict(argstr="--dimest=%s",),
        environ=dict(nohash=True, usedefault=True,),
        epsilon=dict(argstr="--eps=%f",),
        epsilonS=dict(argstr="--epsS=%f",),
        in_files=dict(argstr="-i %s", mandatory=True, position=0, sep=",",),
        log_power=dict(argstr="--logPower",),
        mask=dict(argstr="-m %s", extensions=None,),
        max_restart=dict(argstr="--maxrestart=%d",),
        maxit=dict(argstr="--maxit=%d",),
        migp=dict(argstr="--migp",),
        migpN=dict(argstr="--migpN %d",),
        migp_factor=dict(argstr="--migp_factor %d",),
        migp_shuffle=dict(argstr="--migp_shuffle",),
        mix=dict(argstr="--mix=%s", extensions=None,),
        mm_thresh=dict(argstr="--mmthresh=%f",),
        no_bet=dict(argstr="--nobet",),
        no_mask=dict(argstr="--nomask",),
        no_mm=dict(argstr="--no_mm",),
        non_linearity=dict(argstr="--nl=%s",),
        num_ICs=dict(argstr="-n %d",),
        out_all=dict(argstr="--Oall",),
        out_dir=dict(argstr="-o %s", genfile=True,),
        out_mean=dict(argstr="--Omean",),
        out_orig=dict(argstr="--Oorig",),
        out_pca=dict(argstr="--Opca",),
        out_stats=dict(argstr="--Ostats",),
        out_unmix=dict(argstr="--Ounmix",),
        out_white=dict(argstr="--Owhite",),
        output_type=dict(),
        pbsc=dict(argstr="--pbsc",),
        rem_cmp=dict(argstr="-f %d",),
        remove_deriv=dict(argstr="--remove_deriv",),
        report=dict(argstr="--report",),
        report_maps=dict(argstr="--report_maps=%s",),
        s_con=dict(argstr="--Scon=%s", extensions=None,),
        s_des=dict(argstr="--Sdes=%s", extensions=None,),
        sep_vn=dict(argstr="--sep_vn",),
        sep_whiten=dict(argstr="--sep_whiten",),
        smode=dict(argstr="--smode=%s", extensions=None,),
        t_con=dict(argstr="--Tcon=%s", extensions=None,),
        t_des=dict(argstr="--Tdes=%s", extensions=None,),
        tr_sec=dict(argstr="--tr=%f",),
        update_mask=dict(argstr="--update_mask",),
        var_norm=dict(argstr="--vn",),
    )
    inputs = MELODIC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MELODIC_outputs():
    output_map = dict(out_dir=dict(), report_dir=dict(),)
    outputs = MELODIC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractFiberTracking


def test_gtractFiberTracking_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        branchingAngle=dict(argstr="--branchingAngle %f",),
        branchingThreshold=dict(argstr="--branchingThreshold %f",),
        curvatureThreshold=dict(argstr="--curvatureThreshold %f",),
        endingSeedsLabel=dict(argstr="--endingSeedsLabel %d",),
        environ=dict(nohash=True, usedefault=True,),
        guidedCurvatureThreshold=dict(argstr="--guidedCurvatureThreshold %f",),
        inputAnisotropyVolume=dict(
            argstr="--inputAnisotropyVolume %s", extensions=None,
        ),
        inputEndingSeedsLabelMapVolume=dict(
            argstr="--inputEndingSeedsLabelMapVolume %s", extensions=None,
        ),
        inputStartingSeedsLabelMapVolume=dict(
            argstr="--inputStartingSeedsLabelMapVolume %s", extensions=None,
        ),
        inputTensorVolume=dict(argstr="--inputTensorVolume %s", extensions=None,),
        inputTract=dict(argstr="--inputTract %s", extensions=None,),
        maximumBranchPoints=dict(argstr="--maximumBranchPoints %d",),
        maximumGuideDistance=dict(argstr="--maximumGuideDistance %f",),
        maximumLength=dict(argstr="--maximumLength %f",),
        minimumLength=dict(argstr="--minimumLength %f",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputTract=dict(argstr="--outputTract %s", hash_files=False,),
        randomSeed=dict(argstr="--randomSeed %d",),
        seedThreshold=dict(argstr="--seedThreshold %f",),
        startingSeedsLabel=dict(argstr="--startingSeedsLabel %d",),
        stepSize=dict(argstr="--stepSize %f",),
        tendF=dict(argstr="--tendF %f",),
        tendG=dict(argstr="--tendG %f",),
        trackingMethod=dict(argstr="--trackingMethod %s",),
        trackingThreshold=dict(argstr="--trackingThreshold %f",),
        useLoopDetection=dict(argstr="--useLoopDetection ",),
        useRandomWalk=dict(argstr="--useRandomWalk ",),
        useTend=dict(argstr="--useTend ",),
        writeXMLPolyDataFile=dict(argstr="--writeXMLPolyDataFile ",),
    )
    inputs = gtractFiberTracking.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractFiberTracking_outputs():
    output_map = dict(outputTract=dict(extensions=None,),)
    outputs = gtractFiberTracking.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import FindCenterOfBrain


def test_FindCenterOfBrain_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        axis=dict(argstr="--axis %d",),
        backgroundValue=dict(argstr="--backgroundValue %d",),
        clippedImageMask=dict(argstr="--clippedImageMask %s", hash_files=False,),
        closingSize=dict(argstr="--closingSize %d",),
        debugAfterGridComputationsForegroundImage=dict(
            argstr="--debugAfterGridComputationsForegroundImage %s", hash_files=False,
        ),
        debugClippedImageMask=dict(
            argstr="--debugClippedImageMask %s", hash_files=False,
        ),
        debugDistanceImage=dict(argstr="--debugDistanceImage %s", hash_files=False,),
        debugGridImage=dict(argstr="--debugGridImage %s", hash_files=False,),
        debugTrimmedImage=dict(argstr="--debugTrimmedImage %s", hash_files=False,),
        environ=dict(nohash=True, usedefault=True,),
        generateDebugImages=dict(argstr="--generateDebugImages ",),
        headSizeEstimate=dict(argstr="--headSizeEstimate %f",),
        headSizeLimit=dict(argstr="--headSizeLimit %f",),
        imageMask=dict(argstr="--imageMask %s", extensions=None,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        maximize=dict(argstr="--maximize ",),
        otsuPercentileThreshold=dict(argstr="--otsuPercentileThreshold %f",),
    )
    inputs = FindCenterOfBrain.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FindCenterOfBrain_outputs():
    output_map = dict(
        clippedImageMask=dict(extensions=None,),
        debugAfterGridComputationsForegroundImage=dict(extensions=None,),
        debugClippedImageMask=dict(extensions=None,),
        debugDistanceImage=dict(extensions=None,),
        debugGridImage=dict(extensions=None,),
        debugTrimmedImage=dict(extensions=None,),
    )
    outputs = FindCenterOfBrain.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..reconst import EstimateFOD


def test_EstimateFOD_inputs():
    input_map = dict(
        algorithm=dict(argstr="%s", mandatory=True, position=-8,),
        args=dict(argstr="%s",),
        bval_scale=dict(argstr="-bvalue_scaling %s",),
        csf_odf=dict(argstr="%s", extensions=None, position=-1, usedefault=True,),
        csf_txt=dict(argstr="%s", extensions=None, position=-2,),
        environ=dict(nohash=True, usedefault=True,),
        gm_odf=dict(argstr="%s", extensions=None, position=-3, usedefault=True,),
        gm_txt=dict(argstr="%s", extensions=None, position=-4,),
        grad_file=dict(argstr="-grad %s", extensions=None, xor=["grad_fsl"],),
        grad_fsl=dict(argstr="-fslgrad %s %s", xor=["grad_file"],),
        in_bval=dict(extensions=None,),
        in_bvec=dict(argstr="-fslgrad %s %s", extensions=None,),
        in_dirs=dict(argstr="-directions %s", extensions=None,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-7,),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        max_sh=dict(argstr="-lmax %s", sep=",", usedefault=True,),
        nthreads=dict(argstr="-nthreads %d", nohash=True,),
        shell=dict(argstr="-shell %s", sep=",",),
        wm_odf=dict(
            argstr="%s", extensions=None, mandatory=True, position=-5, usedefault=True,
        ),
        wm_txt=dict(argstr="%s", extensions=None, mandatory=True, position=-6,),
    )
    inputs = EstimateFOD.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EstimateFOD_outputs():
    output_map = dict(
        csf_odf=dict(argstr="%s", extensions=None,),
        gm_odf=dict(argstr="%s", extensions=None,),
        wm_odf=dict(argstr="%s", extensions=None,),
    )
    outputs = EstimateFOD.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractFastMarchingTracking


def test_gtractFastMarchingTracking_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        costStepSize=dict(argstr="--costStepSize %f",),
        environ=dict(nohash=True, usedefault=True,),
        inputAnisotropyVolume=dict(
            argstr="--inputAnisotropyVolume %s", extensions=None,
        ),
        inputCostVolume=dict(argstr="--inputCostVolume %s", extensions=None,),
        inputStartingSeedsLabelMapVolume=dict(
            argstr="--inputStartingSeedsLabelMapVolume %s", extensions=None,
        ),
        inputTensorVolume=dict(argstr="--inputTensorVolume %s", extensions=None,),
        maximumStepSize=dict(argstr="--maximumStepSize %f",),
        minimumStepSize=dict(argstr="--minimumStepSize %f",),
        numberOfIterations=dict(argstr="--numberOfIterations %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputTract=dict(argstr="--outputTract %s", hash_files=False,),
        seedThreshold=dict(argstr="--seedThreshold %f",),
        startingSeedsLabel=dict(argstr="--startingSeedsLabel %d",),
        trackingThreshold=dict(argstr="--trackingThreshold %f",),
        writeXMLPolyDataFile=dict(argstr="--writeXMLPolyDataFile ",),
    )
    inputs = gtractFastMarchingTracking.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractFastMarchingTracking_outputs():
    output_map = dict(outputTract=dict(extensions=None,),)
    outputs = gtractFastMarchingTracking.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Tensor2ApparentDiffusion


def test_Tensor2ApparentDiffusion_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debug=dict(argstr="-debug", position=1,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        out_filename=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        quiet=dict(argstr="-quiet", position=1,),
    )
    inputs = Tensor2ApparentDiffusion.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Tensor2ApparentDiffusion_outputs():
    output_map = dict(ADC=dict(extensions=None,),)
    outputs = Tensor2ApparentDiffusion.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Unifize


def test_Unifize_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cl_frac=dict(argstr="-clfrac %f",),
        environ=dict(nohash=True, usedefault=True,),
        epi=dict(argstr="-EPI", requires=["no_duplo", "t2"], xor=["gm"],),
        gm=dict(argstr="-GM",),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        no_duplo=dict(argstr="-noduplo",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_unifized",
        ),
        outputtype=dict(),
        quiet=dict(argstr="-quiet",),
        rbt=dict(argstr="-rbt %f %f %f",),
        scale_file=dict(argstr="-ssave %s", extensions=None,),
        t2=dict(argstr="-T2",),
        t2_up=dict(argstr="-T2up %f",),
        urad=dict(argstr="-Urad %s",),
    )
    inputs = Unifize.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Unifize_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), scale_file=dict(extensions=None,),
    )
    outputs = Unifize.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import ContrastMgr


def test_ContrastMgr_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        contrast_num=dict(argstr="-cope",),
        corrections=dict(copyfile=False, extensions=None, mandatory=True,),
        dof_file=dict(argstr="", copyfile=False, extensions=None, mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        fcon_file=dict(argstr="-f %s", extensions=None,),
        output_type=dict(),
        param_estimates=dict(argstr="", copyfile=False, mandatory=True,),
        sigmasquareds=dict(
            argstr="", copyfile=False, extensions=None, mandatory=True, position=-2,
        ),
        suffix=dict(argstr="-suffix %s",),
        tcon_file=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
    )
    inputs = ContrastMgr.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ContrastMgr_outputs():
    output_map = dict(
        copes=dict(),
        fstats=dict(),
        neffs=dict(),
        tstats=dict(),
        varcopes=dict(),
        zfstats=dict(),
        zstats=dict(),
    )
    outputs = ContrastMgr.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import PicoPDFs


def test_PicoPDFs_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        directmap=dict(argstr="-directmap",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="< %s", extensions=None, mandatory=True, position=1,),
        inputmodel=dict(argstr="-inputmodel %s", position=2, usedefault=True,),
        luts=dict(argstr="-luts %s", mandatory=True,),
        maxcomponents=dict(argstr="-maxcomponents %d", units="NA",),
        numpds=dict(argstr="-numpds %d", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        pdf=dict(argstr="-pdf %s", position=4, usedefault=True,),
    )
    inputs = PicoPDFs.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_PicoPDFs_outputs():
    output_map = dict(pdfs=dict(extensions=None,),)
    outputs = PicoPDFs.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import BrainExtraction


def test_BrainExtraction_inputs():
    input_map = dict(
        anatomical_image=dict(argstr="-a %s", extensions=None, mandatory=True,),
        args=dict(argstr="%s",),
        brain_probability_mask=dict(
            argstr="-m %s", copyfile=False, extensions=None, mandatory=True,
        ),
        brain_template=dict(argstr="-e %s", extensions=None, mandatory=True,),
        debug=dict(argstr="-z 1",),
        dimension=dict(argstr="-d %d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        extraction_registration_mask=dict(argstr="-f %s", extensions=None,),
        image_suffix=dict(argstr="-s %s", usedefault=True,),
        keep_temporary_files=dict(argstr="-k %d",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_prefix=dict(argstr="-o %s", usedefault=True,),
        use_floatingpoint_precision=dict(argstr="-q %d",),
        use_random_seeding=dict(argstr="-u %d",),
    )
    inputs = BrainExtraction.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BrainExtraction_outputs():
    output_map = dict(
        BrainExtractionBrain=dict(extensions=None,),
        BrainExtractionCSF=dict(extensions=None,),
        BrainExtractionGM=dict(extensions=None,),
        BrainExtractionInitialAffine=dict(extensions=None,),
        BrainExtractionInitialAffineFixed=dict(extensions=None,),
        BrainExtractionInitialAffineMoving=dict(extensions=None,),
        BrainExtractionLaplacian=dict(extensions=None,),
        BrainExtractionMask=dict(extensions=None,),
        BrainExtractionPrior0GenericAffine=dict(extensions=None,),
        BrainExtractionPrior1InverseWarp=dict(extensions=None,),
        BrainExtractionPrior1Warp=dict(extensions=None,),
        BrainExtractionPriorWarped=dict(extensions=None,),
        BrainExtractionSegmentation=dict(extensions=None,),
        BrainExtractionTemplateLaplacian=dict(extensions=None,),
        BrainExtractionTmp=dict(extensions=None,),
        BrainExtractionWM=dict(extensions=None,),
        N4Corrected0=dict(extensions=None,),
        N4Truncated0=dict(extensions=None,),
    )
    outputs = BrainExtraction.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..changequantification import IntensityDifferenceMetric


def test_IntensityDifferenceMetric_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        baselineSegmentationVolume=dict(argstr="%s", extensions=None, position=-3,),
        baselineVolume=dict(argstr="%s", extensions=None, position=-4,),
        changingBandSize=dict(argstr="--changingBandSize %d",),
        environ=dict(nohash=True, usedefault=True,),
        followupVolume=dict(argstr="%s", extensions=None, position=-2,),
        outputVolume=dict(argstr="%s", hash_files=False, position=-1,),
        reportFileName=dict(argstr="--reportFileName %s", hash_files=False,),
        sensitivityThreshold=dict(argstr="--sensitivityThreshold %f",),
    )
    inputs = IntensityDifferenceMetric.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_IntensityDifferenceMetric_outputs():
    output_map = dict(
        outputVolume=dict(extensions=None, position=-1,),
        reportFileName=dict(extensions=None,),
    )
    outputs = IntensityDifferenceMetric.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Curvature


def test_Curvature_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        averages=dict(argstr="-a %d",),
        copy_input=dict(),
        distances=dict(argstr="-distances %d %d",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=True, extensions=None, mandatory=True, position=-2,
        ),
        n=dict(argstr="-n",),
        save=dict(argstr="-w",),
        subjects_dir=dict(),
        threshold=dict(argstr="-thresh %.3f",),
    )
    inputs = Curvature.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Curvature_outputs():
    output_map = dict(
        out_gauss=dict(extensions=None,), out_mean=dict(extensions=None,),
    )
    outputs = Curvature.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import GLMFit


def test_GLMFit_inputs():
    input_map = dict(
        allow_ill_cond=dict(argstr="--illcond",),
        allow_repeated_subjects=dict(argstr="--allowsubjrep",),
        args=dict(argstr="%s",),
        calc_AR1=dict(argstr="--tar1",),
        check_opts=dict(argstr="--checkopts",),
        compute_log_y=dict(argstr="--logy",),
        contrast=dict(argstr="--C %s...",),
        cortex=dict(argstr="--cortex", xor=["label_file"],),
        debug=dict(argstr="--debug",),
        design=dict(
            argstr="--X %s", extensions=None, xor=("fsgd", "design", "one_sample"),
        ),
        diag=dict(argstr="--diag %d",),
        diag_cluster=dict(argstr="--diag-cluster",),
        environ=dict(nohash=True, usedefault=True,),
        fixed_fx_dof=dict(argstr="--ffxdof %d", xor=["fixed_fx_dof_file"],),
        fixed_fx_dof_file=dict(
            argstr="--ffxdofdat %d", extensions=None, xor=["fixed_fx_dof"],
        ),
        fixed_fx_var=dict(argstr="--yffxvar %s", extensions=None,),
        force_perm=dict(argstr="--perm-force",),
        fsgd=dict(argstr="--fsgd %s %s", xor=("fsgd", "design", "one_sample"),),
        fwhm=dict(argstr="--fwhm %f",),
        glm_dir=dict(argstr="--glmdir %s", genfile=True,),
        hemi=dict(),
        in_file=dict(argstr="--y %s", copyfile=False, extensions=None, mandatory=True,),
        invert_mask=dict(argstr="--mask-inv",),
        label_file=dict(argstr="--label %s", extensions=None, xor=["cortex"],),
        mask_file=dict(argstr="--mask %s", extensions=None,),
        no_contrast_ok=dict(argstr="--no-contrasts-ok",),
        no_est_fwhm=dict(argstr="--no-est-fwhm",),
        no_mask_smooth=dict(argstr="--no-mask-smooth",),
        no_prune=dict(argstr="--no-prune", xor=["prunethresh"],),
        one_sample=dict(
            argstr="--osgm", xor=("one_sample", "fsgd", "design", "contrast"),
        ),
        pca=dict(argstr="--pca",),
        per_voxel_reg=dict(argstr="--pvr %s...",),
        profile=dict(argstr="--profile %d",),
        prune=dict(argstr="--prune",),
        prune_thresh=dict(argstr="--prune_thr %f", xor=["noprune"],),
        resynth_test=dict(argstr="--resynthtest %d",),
        save_cond=dict(argstr="--save-cond",),
        save_estimate=dict(argstr="--yhat-save",),
        save_res_corr_mtx=dict(argstr="--eres-scm",),
        save_residual=dict(argstr="--eres-save",),
        seed=dict(argstr="--seed %d",),
        self_reg=dict(argstr="--selfreg %d %d %d",),
        sim_done_file=dict(argstr="--sim-done %s", extensions=None,),
        sim_sign=dict(argstr="--sim-sign %s",),
        simulation=dict(argstr="--sim %s %d %f %s",),
        subject_id=dict(),
        subjects_dir=dict(),
        surf=dict(argstr="--surf %s %s %s", requires=["subject_id", "hemi"],),
        surf_geo=dict(usedefault=True,),
        synth=dict(argstr="--synth",),
        uniform=dict(argstr="--uniform %f %f",),
        var_fwhm=dict(argstr="--var-fwhm %f",),
        vox_dump=dict(argstr="--voxdump %d %d %d",),
        weight_file=dict(extensions=None, xor=["weighted_ls"],),
        weight_inv=dict(argstr="--w-inv", xor=["weighted_ls"],),
        weight_sqrt=dict(argstr="--w-sqrt", xor=["weighted_ls"],),
        weighted_ls=dict(
            argstr="--wls %s",
            extensions=None,
            xor=("weight_file", "weight_inv", "weight_sqrt"),
        ),
    )
    inputs = GLMFit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GLMFit_outputs():
    output_map = dict(
        beta_file=dict(extensions=None,),
        dof_file=dict(extensions=None,),
        error_file=dict(extensions=None,),
        error_stddev_file=dict(extensions=None,),
        error_var_file=dict(extensions=None,),
        estimate_file=dict(extensions=None,),
        frame_eigenvectors=dict(extensions=None,),
        ftest_file=dict(),
        fwhm_file=dict(extensions=None,),
        gamma_file=dict(),
        gamma_var_file=dict(),
        glm_dir=dict(),
        mask_file=dict(extensions=None,),
        sig_file=dict(),
        singular_values=dict(extensions=None,),
        spatial_eigenvectors=dict(extensions=None,),
        svd_stats_file=dict(extensions=None,),
    )
    outputs = GLMFit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import SynthesizeFLASH


def test_SynthesizeFLASH_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fixed_weighting=dict(argstr="-w", position=1,),
        flip_angle=dict(argstr="%.2f", mandatory=True, position=3,),
        out_file=dict(argstr="%s", extensions=None, genfile=True,),
        pd_image=dict(argstr="%s", extensions=None, mandatory=True, position=6,),
        subjects_dir=dict(),
        t1_image=dict(argstr="%s", extensions=None, mandatory=True, position=5,),
        te=dict(argstr="%.3f", mandatory=True, position=4,),
        tr=dict(argstr="%.2f", mandatory=True, position=2,),
    )
    inputs = SynthesizeFLASH.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SynthesizeFLASH_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = SynthesizeFLASH.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import XfmConcat


def test_XfmConcat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        input_files=dict(argstr="%s", mandatory=True, position=-2, sep=" ",),
        input_grid_files=dict(),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_files"],
            name_template="%s_xfmconcat.xfm",
            position=-1,
        ),
        verbose=dict(argstr="-verbose",),
    )
    inputs = XfmConcat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_XfmConcat_outputs():
    output_map = dict(output_file=dict(extensions=None,), output_grids=dict(),)
    outputs = XfmConcat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Math


def test_Math_inputs():
    input_map = dict(
        abs=dict(argstr="-abs",),
        args=dict(argstr="%s",),
        calc_add=dict(argstr="-add",),
        calc_and=dict(argstr="-and",),
        calc_div=dict(argstr="-div",),
        calc_mul=dict(argstr="-mult",),
        calc_not=dict(argstr="-not",),
        calc_or=dict(argstr="-or",),
        calc_sub=dict(argstr="-sub",),
        check_dimensions=dict(
            argstr="-check_dimensions", xor=("check_dimensions", "no_check_dimensions"),
        ),
        clamp=dict(argstr="-clamp -const2 %s %s",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        copy_header=dict(argstr="-copy_header", xor=("copy_header", "no_copy_header"),),
        count_valid=dict(argstr="-count_valid",),
        dimension=dict(argstr="-dimension %s",),
        environ=dict(nohash=True, usedefault=True,),
        exp=dict(argstr="-exp -const2 %s %s",),
        filelist=dict(
            argstr="-filelist %s",
            extensions=None,
            mandatory=True,
            xor=("input_files", "filelist"),
        ),
        format_byte=dict(
            argstr="-byte",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_double=dict(
            argstr="-double",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_filetype=dict(
            argstr="-filetype",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_float=dict(
            argstr="-float",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_int=dict(
            argstr="-int",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_long=dict(
            argstr="-long",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_short=dict(
            argstr="-short",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_signed=dict(
            argstr="-signed",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_unsigned=dict(
            argstr="-unsigned",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        ignore_nan=dict(argstr="-ignore_nan",),
        input_files=dict(
            argstr="%s",
            mandatory=True,
            position=-2,
            sep=" ",
            xor=("input_files", "filelist"),
        ),
        invert=dict(argstr="-invert -const %s",),
        isnan=dict(argstr="-isnan",),
        log=dict(argstr="-log -const2 %s %s",),
        max_buffer_size_in_kb=dict(
            argstr="-max_buffer_size_in_kb %d", usedefault=True,
        ),
        maximum=dict(argstr="-maximum",),
        minimum=dict(argstr="-minimum",),
        nisnan=dict(argstr="-nisnan",),
        no_check_dimensions=dict(
            argstr="-nocheck_dimensions",
            xor=("check_dimensions", "no_check_dimensions"),
        ),
        no_copy_header=dict(
            argstr="-nocopy_header", xor=("copy_header", "no_copy_header"),
        ),
        nsegment=dict(argstr="-nsegment -const2 %s %s",),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_files"],
            name_template="%s_mincmath.mnc",
            position=-1,
        ),
        output_illegal=dict(
            argstr="-illegal_value",
            xor=("output_nan", "output_zero", "output_illegal_value"),
        ),
        output_nan=dict(
            argstr="-nan", xor=("output_nan", "output_zero", "output_illegal_value"),
        ),
        output_zero=dict(
            argstr="-zero", xor=("output_nan", "output_zero", "output_illegal_value"),
        ),
        percentdiff=dict(argstr="-percentdiff",),
        propagate_nan=dict(argstr="-propagate_nan",),
        scale=dict(argstr="-scale -const2 %s %s",),
        segment=dict(argstr="-segment -const2 %s %s",),
        sqrt=dict(argstr="-sqrt",),
        square=dict(argstr="-square",),
        test_eq=dict(argstr="-eq",),
        test_ge=dict(argstr="-ge",),
        test_gt=dict(argstr="-gt",),
        test_le=dict(argstr="-le",),
        test_lt=dict(argstr="-lt",),
        test_ne=dict(argstr="-ne",),
        two=dict(argstr="-2",),
        voxel_range=dict(argstr="-range %d %d",),
    )
    inputs = Math.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Math_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = Math.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import SliceTimer


def test_SliceTimer_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        custom_order=dict(argstr="--ocustom=%s", extensions=None,),
        custom_timings=dict(argstr="--tcustom=%s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        global_shift=dict(argstr="--tglobal",),
        in_file=dict(argstr="--in=%s", extensions=None, mandatory=True, position=0,),
        index_dir=dict(argstr="--down",),
        interleaved=dict(argstr="--odd",),
        out_file=dict(
            argstr="--out=%s", extensions=None, genfile=True, hash_files=False,
        ),
        output_type=dict(),
        slice_direction=dict(argstr="--direction=%d",),
        time_repetition=dict(argstr="--repeat=%f",),
    )
    inputs = SliceTimer.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SliceTimer_outputs():
    output_map = dict(slice_time_corrected_file=dict(extensions=None,),)
    outputs = SliceTimer.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import Rigid


def test_Rigid_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fixed_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=0,
        ),
        ftol=dict(argstr="%g", mandatory=True, position=4, usedefault=True,),
        initialize_xfm=dict(argstr="%s", copyfile=True, extensions=None, position=5,),
        moving_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=1,
        ),
        sampling_xyz=dict(
            argstr="%g %g %g", mandatory=True, position=3, usedefault=True,
        ),
        similarity_metric=dict(
            argstr="%s", mandatory=True, position=2, usedefault=True,
        ),
    )
    inputs = Rigid.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Rigid_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), out_file_xfm=dict(extensions=None,),
    )
    outputs = Rigid.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import JointFusion


def test_JointFusion_inputs():
    input_map = dict(
        alpha=dict(argstr="-a %s", usedefault=True,),
        args=dict(argstr="%s",),
        atlas_image=dict(argstr="-g %s...", mandatory=True,),
        atlas_segmentation_image=dict(argstr="-l %s...", mandatory=True,),
        beta=dict(argstr="-b %s", usedefault=True,),
        constrain_nonnegative=dict(argstr="-c", usedefault=True,),
        dimension=dict(argstr="-d %d",),
        environ=dict(nohash=True, usedefault=True,),
        exclusion_image=dict(),
        exclusion_image_label=dict(argstr="-e %s", requires=["exclusion_image"],),
        mask_image=dict(argstr="-x %s", extensions=None,),
        num_threads=dict(nohash=True, usedefault=True,),
        out_atlas_voting_weight_name_format=dict(
            requires=[
                "out_label_fusion",
                "out_intensity_fusion_name_format",
                "out_label_post_prob_name_format",
            ],
        ),
        out_intensity_fusion_name_format=dict(argstr="",),
        out_label_fusion=dict(argstr="%s", extensions=None, hash_files=False,),
        out_label_post_prob_name_format=dict(
            requires=["out_label_fusion", "out_intensity_fusion_name_format"],
        ),
        patch_metric=dict(argstr="-m %s",),
        patch_radius=dict(argstr="-p %s", maxlen=3, minlen=3,),
        retain_atlas_voting_images=dict(argstr="-f", usedefault=True,),
        retain_label_posterior_images=dict(
            argstr="-r", requires=["atlas_segmentation_image"], usedefault=True,
        ),
        search_radius=dict(argstr="-s %s", usedefault=True,),
        target_image=dict(argstr="-t %s", mandatory=True,),
        verbose=dict(argstr="-v",),
    )
    inputs = JointFusion.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JointFusion_outputs():
    output_map = dict(
        out_atlas_voting_weight=dict(),
        out_intensity_fusion=dict(),
        out_label_fusion=dict(extensions=None,),
        out_label_post_prob=dict(),
    )
    outputs = JointFusion.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import Registration


def test_Registration_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fixed_image=dict(argstr="-f %s", extensions=None, mandatory=True,),
        fixed_mask=dict(argstr="-fMask %s", extensions=None,),
        initial_transform=dict(argstr="-t0 %s", extensions=None,),
        moving_image=dict(argstr="-m %s", extensions=None, mandatory=True,),
        moving_mask=dict(argstr="-mMask %s", extensions=None,),
        num_threads=dict(argstr="-threads %01d", nohash=True, usedefault=True,),
        output_path=dict(argstr="-out %s", mandatory=True, usedefault=True,),
        parameters=dict(argstr="-p %s...", mandatory=True,),
    )
    inputs = Registration.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Registration_outputs():
    output_map = dict(
        transform=dict(),
        warped_file=dict(extensions=None,),
        warped_files=dict(),
        warped_files_flags=dict(),
    )
    outputs = Registration.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import FixTopology


def test_FixTopology_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        copy_inputs=dict(mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        ga=dict(argstr="-ga",),
        hemisphere=dict(argstr="%s", mandatory=True, position=-1,),
        in_brain=dict(extensions=None, mandatory=True,),
        in_inflated=dict(extensions=None, mandatory=True,),
        in_orig=dict(extensions=None, mandatory=True,),
        in_wm=dict(extensions=None, mandatory=True,),
        mgz=dict(argstr="-mgz",),
        seed=dict(argstr="-seed %d",),
        sphere=dict(argstr="-sphere %s", extensions=None,),
        subject_id=dict(argstr="%s", mandatory=True, position=-2, usedefault=True,),
        subjects_dir=dict(),
    )
    inputs = FixTopology.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FixTopology_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = FixTopology.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Label2Annot


def test_Label2Annot_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        color_table=dict(argstr="--ctab %s", extensions=None,),
        copy_inputs=dict(),
        environ=dict(nohash=True, usedefault=True,),
        hemisphere=dict(argstr="--hemi %s", mandatory=True,),
        in_labels=dict(argstr="--l %s...", mandatory=True,),
        keep_max=dict(argstr="--maxstatwinner",),
        orig=dict(extensions=None, mandatory=True,),
        out_annot=dict(argstr="--a %s", mandatory=True,),
        subject_id=dict(argstr="--s %s", mandatory=True, usedefault=True,),
        subjects_dir=dict(),
        verbose_off=dict(argstr="--noverbose",),
    )
    inputs = Label2Annot.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Label2Annot_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Label2Annot.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import AnalyzeWarp


def test_AnalyzeWarp_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        jac=dict(argstr="-jac %s", usedefault=True,),
        jacmat=dict(argstr="-jacmat %s", usedefault=True,),
        moving_image=dict(argstr="-in %s", extensions=None,),
        num_threads=dict(argstr="-threads %01d", nohash=True, usedefault=True,),
        output_path=dict(argstr="-out %s", mandatory=True, usedefault=True,),
        points=dict(argstr="-def %s", position=0, usedefault=True,),
        transform_file=dict(argstr="-tp %s", extensions=None, mandatory=True,),
    )
    inputs = AnalyzeWarp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AnalyzeWarp_outputs():
    output_map = dict(
        disp_field=dict(extensions=None,),
        jacdet_map=dict(extensions=None,),
        jacmat_map=dict(extensions=None,),
    )
    outputs = AnalyzeWarp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import RobustFOV


def test_RobustFOV_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        brainsize=dict(argstr="-b %d",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True, position=0,),
        out_roi=dict(
            argstr="-r %s",
            extensions=None,
            hash_files=False,
            name_source=["in_file"],
            name_template="%s_ROI",
        ),
        out_transform=dict(
            argstr="-m %s",
            extensions=None,
            hash_files=False,
            name_source=["in_file"],
            name_template="%s_to_ROI",
        ),
        output_type=dict(),
    )
    inputs = RobustFOV.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RobustFOV_outputs():
    output_map = dict(
        out_roi=dict(extensions=None,), out_transform=dict(extensions=None,),
    )
    outputs = RobustFOV.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import CenterMass


def test_CenterMass_inputs():
    input_map = dict(
        all_rois=dict(argstr="-all_rois",),
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask",),
        cm_file=dict(
            argstr="> %s",
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source="in_file",
            name_template="%s_cm.out",
            position=-1,
        ),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=True, extensions=None, mandatory=True, position=-2,
        ),
        local_ijk=dict(argstr="-local_ijk",),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        roi_vals=dict(argstr="-roi_vals %s",),
        set_cm=dict(argstr="-set %f %f %f",),
    )
    inputs = CenterMass.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CenterMass_outputs():
    output_map = dict(
        cm=dict(), cm_file=dict(extensions=None,), out_file=dict(extensions=None,),
    )
    outputs = CenterMass.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..maths import ErodeImage


def test_ErodeImage_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        internal_datatype=dict(argstr="-dt %s", position=1,),
        kernel_file=dict(
            argstr="%s", extensions=None, position=5, xor=["kernel_size"],
        ),
        kernel_shape=dict(argstr="-kernel %s", position=4,),
        kernel_size=dict(argstr="%.4f", position=5, xor=["kernel_file"],),
        minimum_filter=dict(argstr="%s", position=6, usedefault=True,),
        nan2zeros=dict(argstr="-nan", position=3,),
        out_file=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False, position=-2,
        ),
        output_datatype=dict(argstr="-odt %s", position=-1,),
        output_type=dict(),
    )
    inputs = ErodeImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ErodeImage_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ErodeImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Zcat


def test_Zcat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        datum=dict(argstr="-datum %s",),
        environ=dict(nohash=True, usedefault=True,),
        fscale=dict(argstr="-fscale", xor=["nscale"],),
        in_files=dict(argstr="%s", copyfile=False, mandatory=True, position=-1,),
        nscale=dict(argstr="-nscale", xor=["fscale"],),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_files",
            name_template="%s_zcat",
        ),
        outputtype=dict(),
        verb=dict(argstr="-verb",),
    )
    inputs = Zcat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Zcat_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Zcat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..maths import MeanImage


def test_MeanImage_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="-%smean", position=4, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        internal_datatype=dict(argstr="-dt %s", position=1,),
        nan2zeros=dict(argstr="-nan", position=3,),
        out_file=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False, position=-2,
        ),
        output_datatype=dict(argstr="-odt %s", position=-1,),
        output_type=dict(),
    )
    inputs = MeanImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MeanImage_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = MeanImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Dfs


def test_Dfs_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        curvatureWeighting=dict(argstr="-w %f", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        inputShadingVolume=dict(argstr="-c %s", extensions=None,),
        inputVolumeFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        noNormalsFlag=dict(argstr="--nonormals",),
        nonZeroTessellation=dict(
            argstr="-nz", xor=("nonZeroTessellation", "specialTessellation"),
        ),
        outputSurfaceFile=dict(argstr="-o %s", extensions=None, genfile=True,),
        postSmoothFlag=dict(argstr="--postsmooth",),
        scalingPercentile=dict(argstr="-f %f",),
        smoothingConstant=dict(argstr="-a %f", usedefault=True,),
        smoothingIterations=dict(argstr="-n %d", usedefault=True,),
        specialTessellation=dict(
            argstr="%s",
            position=-1,
            requires=["tessellationThreshold"],
            xor=("nonZeroTessellation", "specialTessellation"),
        ),
        tessellationThreshold=dict(argstr="%f",),
        timer=dict(argstr="--timer",),
        verbosity=dict(argstr="-v %d",),
        zeroPadFlag=dict(argstr="-z",),
    )
    inputs = Dfs.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Dfs_outputs():
    output_map = dict(outputSurfaceFile=dict(extensions=None,),)
    outputs = Dfs.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ImageStats


def test_ImageStats_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=3,),
        index_mask_file=dict(argstr="-K %s", extensions=None, position=2,),
        mask_file=dict(argstr="", extensions=None,),
        op_string=dict(argstr="%s", mandatory=True, position=4,),
        output_type=dict(),
        split_4d=dict(argstr="-t", position=1,),
    )
    inputs = ImageStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ImageStats_outputs():
    output_map = dict(out_stat=dict(),)
    outputs = ImageStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..aroma import ICA_AROMA


def test_ICA_AROMA_inputs():
    input_map = dict(
        TR=dict(argstr="-tr %.3f",),
        args=dict(argstr="%s",),
        denoise_type=dict(argstr="-den %s", mandatory=True, usedefault=True,),
        dim=dict(argstr="-dim %d",),
        environ=dict(nohash=True, usedefault=True,),
        feat_dir=dict(
            argstr="-feat %s",
            mandatory=True,
            xor=["in_file", "mat_file", "fnirt_warp_file", "motion_parameters"],
        ),
        fnirt_warp_file=dict(argstr="-warp %s", extensions=None, xor=["feat_dir"],),
        in_file=dict(
            argstr="-i %s", extensions=None, mandatory=True, xor=["feat_dir"],
        ),
        mask=dict(argstr="-m %s", extensions=None, xor=["feat_dir"],),
        mat_file=dict(argstr="-affmat %s", extensions=None, xor=["feat_dir"],),
        melodic_dir=dict(argstr="-meldir %s",),
        motion_parameters=dict(
            argstr="-mc %s", extensions=None, mandatory=True, xor=["feat_dir"],
        ),
        out_dir=dict(argstr="-o %s", mandatory=True, usedefault=True,),
    )
    inputs = ICA_AROMA.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ICA_AROMA_outputs():
    output_map = dict(
        aggr_denoised_file=dict(extensions=None,),
        nonaggr_denoised_file=dict(extensions=None,),
        out_dir=dict(),
    )
    outputs = ICA_AROMA.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..featuredetection import CannySegmentationLevelSetImageFilter


def test_CannySegmentationLevelSetImageFilter_inputs():
    input_map = dict(
        advectionWeight=dict(argstr="--advectionWeight %f",),
        args=dict(argstr="%s",),
        cannyThreshold=dict(argstr="--cannyThreshold %f",),
        cannyVariance=dict(argstr="--cannyVariance %f",),
        environ=dict(nohash=True, usedefault=True,),
        initialModel=dict(argstr="--initialModel %s", extensions=None,),
        initialModelIsovalue=dict(argstr="--initialModelIsovalue %f",),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        maxIterations=dict(argstr="--maxIterations %d",),
        outputSpeedVolume=dict(argstr="--outputSpeedVolume %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
    )
    inputs = CannySegmentationLevelSetImageFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CannySegmentationLevelSetImageFilter_outputs():
    output_map = dict(
        outputSpeedVolume=dict(extensions=None,), outputVolume=dict(extensions=None,),
    )
    outputs = CannySegmentationLevelSetImageFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import SampleToSurface


def test_SampleToSurface_inputs():
    input_map = dict(
        apply_rot=dict(argstr="--rot %.3f %.3f %.3f",),
        apply_trans=dict(argstr="--trans %.3f %.3f %.3f",),
        args=dict(argstr="%s",),
        cortex_mask=dict(argstr="--cortex", xor=["mask_label"],),
        environ=dict(nohash=True, usedefault=True,),
        fix_tk_reg=dict(argstr="--fixtkreg",),
        float2int_method=dict(argstr="--float2int %s",),
        frame=dict(argstr="--frame %d",),
        hemi=dict(argstr="--hemi %s", mandatory=True,),
        hits_file=dict(argstr="--srchit %s",),
        hits_type=dict(argstr="--srchit_type",),
        ico_order=dict(argstr="--icoorder %d", requires=["target_subject"],),
        interp_method=dict(argstr="--interp %s",),
        mask_label=dict(argstr="--mask %s", extensions=None, xor=["cortex_mask"],),
        mni152reg=dict(
            argstr="--mni152reg",
            mandatory=True,
            xor=["reg_file", "reg_header", "mni152reg"],
        ),
        no_reshape=dict(argstr="--noreshape", xor=["reshape"],),
        out_file=dict(argstr="--o %s", extensions=None, genfile=True,),
        out_type=dict(argstr="--out_type %s",),
        override_reg_subj=dict(argstr="--srcsubject %s", requires=["subject_id"],),
        projection_stem=dict(mandatory=True, xor=["sampling_method"],),
        reference_file=dict(argstr="--ref %s", extensions=None,),
        reg_file=dict(
            argstr="--reg %s",
            extensions=None,
            mandatory=True,
            xor=["reg_file", "reg_header", "mni152reg"],
        ),
        reg_header=dict(
            argstr="--regheader %s",
            mandatory=True,
            requires=["subject_id"],
            xor=["reg_file", "reg_header", "mni152reg"],
        ),
        reshape=dict(argstr="--reshape", xor=["no_reshape"],),
        reshape_slices=dict(argstr="--rf %d",),
        sampling_method=dict(
            argstr="%s",
            mandatory=True,
            requires=["sampling_range", "sampling_units"],
            xor=["projection_stem"],
        ),
        sampling_range=dict(),
        sampling_units=dict(),
        scale_input=dict(argstr="--scale %.3f",),
        smooth_surf=dict(argstr="--surf-fwhm %.3f",),
        smooth_vol=dict(argstr="--fwhm %.3f",),
        source_file=dict(argstr="--mov %s", extensions=None, mandatory=True,),
        subject_id=dict(),
        subjects_dir=dict(),
        surf_reg=dict(argstr="--surfreg %s", requires=["target_subject"],),
        surface=dict(argstr="--surf %s",),
        target_subject=dict(argstr="--trgsubject %s",),
        vox_file=dict(argstr="--nvox %s",),
    )
    inputs = SampleToSurface.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SampleToSurface_outputs():
    output_map = dict(
        hits_file=dict(extensions=None,),
        out_file=dict(extensions=None,),
        vox_file=dict(extensions=None,),
    )
    outputs = SampleToSurface.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..regutils import RegJacobian


def test_RegJacobian_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        omp_core_val=dict(argstr="-omp %i", usedefault=True,),
        out_file=dict(
            argstr="%s",
            extensions=None,
            name_source=["trans_file"],
            name_template="%s",
            position=-1,
        ),
        ref_file=dict(argstr="-ref %s", extensions=None,),
        trans_file=dict(argstr="-trans %s", extensions=None, mandatory=True,),
        type=dict(argstr="-%s", position=-2, usedefault=True,),
    )
    inputs = RegJacobian.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegJacobian_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = RegJacobian.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MakeAverageSubject


def test_MakeAverageSubject_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        out_name=dict(argstr="--out %s", extensions=None, usedefault=True,),
        subjects_dir=dict(),
        subjects_ids=dict(argstr="--subjects %s", mandatory=True, sep=" ",),
    )
    inputs = MakeAverageSubject.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MakeAverageSubject_outputs():
    output_map = dict(average_subject_name=dict(),)
    outputs = MakeAverageSubject.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ImageMeants


def test_ImageMeants_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        eig=dict(argstr="--eig",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True, position=0,),
        mask=dict(argstr="-m %s", extensions=None,),
        nobin=dict(argstr="--no_bin",),
        order=dict(argstr="--order=%d", usedefault=True,),
        out_file=dict(argstr="-o %s", extensions=None, genfile=True, hash_files=False,),
        output_type=dict(),
        show_all=dict(argstr="--showall",),
        spatial_coord=dict(argstr="-c %s",),
        transpose=dict(argstr="--transpose",),
        use_mm=dict(argstr="--usemm",),
    )
    inputs = ImageMeants.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ImageMeants_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ImageMeants.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Maskave


def test_Maskave_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-2,
        ),
        mask=dict(argstr="-mask %s", extensions=None, position=1,),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="> %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_maskave.1D",
            position=-1,
        ),
        outputtype=dict(),
        quiet=dict(argstr="-quiet", position=2,),
    )
    inputs = Maskave.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Maskave_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Maskave.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Coregister


def test_Coregister_inputs():
    input_map = dict(
        apply_to_files=dict(copyfile=True, field="other",),
        cost_function=dict(field="eoptions.cost_fun",),
        fwhm=dict(field="eoptions.fwhm",),
        jobtype=dict(usedefault=True,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        out_prefix=dict(field="roptions.prefix", usedefault=True,),
        paths=dict(),
        separation=dict(field="eoptions.sep",),
        source=dict(copyfile=True, field="source", mandatory=True,),
        target=dict(
            copyfile=False,
            extensions=[".hdr", ".img", ".img.gz", ".nii"],
            field="ref",
            mandatory=True,
        ),
        tolerance=dict(field="eoptions.tol",),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        write_interp=dict(field="roptions.interp",),
        write_mask=dict(field="roptions.mask",),
        write_wrap=dict(field="roptions.wrap",),
    )
    inputs = Coregister.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Coregister_outputs():
    output_map = dict(coregistered_files=dict(), coregistered_source=dict(),)
    outputs = Coregister.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..legacy import buildtemplateparallel


def test_buildtemplateparallel_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bias_field_correction=dict(argstr="-n 1",),
        dimension=dict(argstr="-d %d", position=1, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        gradient_step_size=dict(argstr="-g %f",),
        in_files=dict(argstr="%s", mandatory=True, position=-1,),
        iteration_limit=dict(argstr="-i %d", usedefault=True,),
        max_iterations=dict(argstr="-m %s", sep="x",),
        num_cores=dict(argstr="-j %d", requires=["parallelization"],),
        num_threads=dict(nohash=True, usedefault=True,),
        out_prefix=dict(argstr="-o %s", usedefault=True,),
        parallelization=dict(argstr="-c %d", usedefault=True,),
        rigid_body_registration=dict(argstr="-r 1",),
        similarity_metric=dict(argstr="-s %s",),
        transformation_model=dict(argstr="-t %s", usedefault=True,),
        use_first_as_target=dict(),
    )
    inputs = buildtemplateparallel.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_buildtemplateparallel_outputs():
    output_map = dict(
        final_template_file=dict(extensions=None,),
        subject_outfiles=dict(),
        template_files=dict(),
    )
    outputs = buildtemplateparallel.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import RobustStatisticsSegmenter


def test_RobustStatisticsSegmenter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        curvatureWeight=dict(argstr="--curvatureWeight %f",),
        environ=dict(nohash=True, usedefault=True,),
        expectedVolume=dict(argstr="--expectedVolume %f",),
        intensityHomogeneity=dict(argstr="--intensityHomogeneity %f",),
        labelImageFileName=dict(argstr="%s", extensions=None, position=-2,),
        labelValue=dict(argstr="--labelValue %d",),
        maxRunningTime=dict(argstr="--maxRunningTime %f",),
        originalImageFileName=dict(argstr="%s", extensions=None, position=-3,),
        segmentedImageFileName=dict(argstr="%s", hash_files=False, position=-1,),
    )
    inputs = RobustStatisticsSegmenter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RobustStatisticsSegmenter_outputs():
    output_map = dict(segmentedImageFileName=dict(extensions=None, position=-1,),)
    outputs = RobustStatisticsSegmenter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Allineate


def test_Allineate_inputs():
    input_map = dict(
        allcostx=dict(
            argstr="-allcostx |& tee %s",
            extensions=None,
            position=-1,
            xor=["out_file", "out_matrix", "out_param_file", "out_weight_file"],
        ),
        args=dict(argstr="%s",),
        autobox=dict(argstr="-autobox",),
        automask=dict(argstr="-automask+%d",),
        autoweight=dict(argstr="-autoweight%s",),
        center_of_mass=dict(argstr="-cmass%s",),
        check=dict(argstr="-check %s",),
        convergence=dict(argstr="-conv %f",),
        cost=dict(argstr="-cost %s",),
        environ=dict(nohash=True, usedefault=True,),
        epi=dict(argstr="-EPI",),
        final_interpolation=dict(argstr="-final %s",),
        fine_blur=dict(argstr="-fineblur %f",),
        in_file=dict(
            argstr="-source %s", copyfile=False, extensions=None, mandatory=True,
        ),
        in_matrix=dict(
            argstr="-1Dmatrix_apply %s",
            extensions=None,
            position=-3,
            xor=["out_matrix"],
        ),
        in_param_file=dict(
            argstr="-1Dparam_apply %s", extensions=None, xor=["out_param_file"],
        ),
        interpolation=dict(argstr="-interp %s",),
        master=dict(argstr="-master %s", extensions=None,),
        maxrot=dict(argstr="-maxrot %f",),
        maxscl=dict(argstr="-maxscl %f",),
        maxshf=dict(argstr="-maxshf %f",),
        maxshr=dict(argstr="-maxshr %f",),
        newgrid=dict(argstr="-newgrid %f",),
        nmatch=dict(argstr="-nmatch %d",),
        no_pad=dict(argstr="-nopad",),
        nomask=dict(argstr="-nomask",),
        num_threads=dict(nohash=True, usedefault=True,),
        nwarp=dict(argstr="-nwarp %s",),
        nwarp_fixdep=dict(argstr="-nwarp_fixdep%s...",),
        nwarp_fixmot=dict(argstr="-nwarp_fixmot%s...",),
        one_pass=dict(argstr="-onepass",),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            hash_files=False,
            name_source="in_file",
            name_template="%s_allineate",
            xor=["allcostx"],
        ),
        out_matrix=dict(
            argstr="-1Dmatrix_save %s", extensions=None, xor=["in_matrix", "allcostx"],
        ),
        out_param_file=dict(
            argstr="-1Dparam_save %s",
            extensions=None,
            xor=["in_param_file", "allcostx"],
        ),
        out_weight_file=dict(argstr="-wtprefix %s", extensions=None, xor=["allcostx"],),
        outputtype=dict(),
        overwrite=dict(argstr="-overwrite",),
        quiet=dict(argstr="-quiet",),
        reference=dict(argstr="-base %s", extensions=None,),
        replacebase=dict(argstr="-replacebase",),
        replacemeth=dict(argstr="-replacemeth %s",),
        source_automask=dict(argstr="-source_automask+%d",),
        source_mask=dict(argstr="-source_mask %s", extensions=None,),
        two_best=dict(argstr="-twobest %d",),
        two_blur=dict(argstr="-twoblur %f",),
        two_first=dict(argstr="-twofirst",),
        two_pass=dict(argstr="-twopass",),
        usetemp=dict(argstr="-usetemp",),
        verbose=dict(argstr="-verb",),
        warp_type=dict(argstr="-warp %s",),
        warpfreeze=dict(argstr="-warpfreeze",),
        weight=dict(argstr="-weight %s",),
        weight_file=dict(
            argstr="-weight %s", deprecated="1.0.0", extensions=None, new_name="weight",
        ),
        zclip=dict(argstr="-zclip",),
    )
    inputs = Allineate.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Allineate_outputs():
    output_map = dict(
        allcostx=dict(extensions=None,),
        out_file=dict(extensions=None,),
        out_matrix=dict(extensions=None,),
        out_param_file=dict(extensions=None,),
        out_weight_file=dict(extensions=None,),
    )
    outputs = Allineate.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Localstat


def test_Localstat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask",),
        environ=dict(nohash=True, usedefault=True,),
        grid_rmode=dict(argstr="-grid_rmode %s", requires=["reduce_restore_grid"],),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        neighborhood=dict(argstr="-nbhd '%s(%s)'", mandatory=True,),
        nonmask=dict(argstr="-use_nonmask",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_localstat",
            position=0,
        ),
        outputtype=dict(),
        overwrite=dict(argstr="-overwrite",),
        quiet=dict(argstr="-quiet",),
        reduce_grid=dict(
            argstr="-reduce_grid %s", xor=["reduce_restore_grid", "reduce_max_vox"],
        ),
        reduce_max_vox=dict(
            argstr="-reduce_max_vox %s", xor=["reduce_restore_grid", "reduce_grid"],
        ),
        reduce_restore_grid=dict(
            argstr="-reduce_restore_grid %s", xor=["reduce_max_vox", "reduce_grid"],
        ),
        stat=dict(argstr="-stat %s...", mandatory=True,),
    )
    inputs = Localstat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Localstat_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Localstat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import dtiprocess


def test_dtiprocess_inputs():
    input_map = dict(
        DTI_double=dict(argstr="--DTI_double ",),
        RD_output=dict(argstr="--RD_output %s", hash_files=False,),
        affineitk_file=dict(argstr="--affineitk_file %s", extensions=None,),
        args=dict(argstr="%s",),
        color_fa_output=dict(argstr="--color_fa_output %s", hash_files=False,),
        correction=dict(argstr="--correction %s",),
        deformation_output=dict(argstr="--deformation_output %s", hash_files=False,),
        dof_file=dict(argstr="--dof_file %s", extensions=None,),
        dti_image=dict(argstr="--dti_image %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        fa_gradient_output=dict(argstr="--fa_gradient_output %s", hash_files=False,),
        fa_gradmag_output=dict(argstr="--fa_gradmag_output %s", hash_files=False,),
        fa_output=dict(argstr="--fa_output %s", hash_files=False,),
        forward=dict(argstr="--forward %s", extensions=None,),
        frobenius_norm_output=dict(
            argstr="--frobenius_norm_output %s", hash_files=False,
        ),
        hField=dict(argstr="--hField ",),
        interpolation=dict(argstr="--interpolation %s",),
        lambda1_output=dict(argstr="--lambda1_output %s", hash_files=False,),
        lambda2_output=dict(argstr="--lambda2_output %s", hash_files=False,),
        lambda3_output=dict(argstr="--lambda3_output %s", hash_files=False,),
        mask=dict(argstr="--mask %s", extensions=None,),
        md_output=dict(argstr="--md_output %s", hash_files=False,),
        negative_eigenvector_output=dict(
            argstr="--negative_eigenvector_output %s", hash_files=False,
        ),
        newdof_file=dict(argstr="--newdof_file %s", extensions=None,),
        outmask=dict(argstr="--outmask %s", hash_files=False,),
        principal_eigenvector_output=dict(
            argstr="--principal_eigenvector_output %s", hash_files=False,
        ),
        reorientation=dict(argstr="--reorientation %s",),
        rot_output=dict(argstr="--rot_output %s", hash_files=False,),
        scalar_float=dict(argstr="--scalar_float ",),
        sigma=dict(argstr="--sigma %f",),
        verbose=dict(argstr="--verbose ",),
    )
    inputs = dtiprocess.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_dtiprocess_outputs():
    output_map = dict(
        RD_output=dict(extensions=None,),
        color_fa_output=dict(extensions=None,),
        deformation_output=dict(extensions=None,),
        fa_gradient_output=dict(extensions=None,),
        fa_gradmag_output=dict(extensions=None,),
        fa_output=dict(extensions=None,),
        frobenius_norm_output=dict(extensions=None,),
        lambda1_output=dict(extensions=None,),
        lambda2_output=dict(extensions=None,),
        lambda3_output=dict(extensions=None,),
        md_output=dict(extensions=None,),
        negative_eigenvector_output=dict(extensions=None,),
        outmask=dict(extensions=None,),
        principal_eigenvector_output=dict(extensions=None,),
        rot_output=dict(extensions=None,),
    )
    outputs = dtiprocess.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import MRTrixViewer


def test_MRTrixViewer_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debug=dict(argstr="-debug", position=1,),
        environ=dict(nohash=True, usedefault=True,),
        in_files=dict(argstr="%s", mandatory=True, position=-2,),
        quiet=dict(argstr="-quiet", position=1,),
    )
    inputs = MRTrixViewer.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRTrixViewer_outputs():
    output_map = dict()
    outputs = MRTrixViewer.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MaskTool


def test_MaskTool_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        count=dict(argstr="-count", position=2,),
        datum=dict(argstr="-datum %s",),
        dilate_inputs=dict(argstr="-dilate_inputs %s",),
        dilate_results=dict(argstr="-dilate_results %s",),
        environ=dict(nohash=True, usedefault=True,),
        fill_dirs=dict(argstr="-fill_dirs %s", requires=["fill_holes"],),
        fill_holes=dict(argstr="-fill_holes",),
        frac=dict(argstr="-frac %s",),
        in_file=dict(argstr="-input %s", copyfile=False, mandatory=True, position=-1,),
        inter=dict(argstr="-inter",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_mask",
        ),
        outputtype=dict(),
        union=dict(argstr="-union",),
        verbose=dict(argstr="-verb %s",),
    )
    inputs = MaskTool.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MaskTool_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = MaskTool.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..odf import ODFTracker


def test_ODFTracker_inputs():
    input_map = dict(
        ODF=dict(extensions=None, mandatory=True,),
        angle_threshold=dict(argstr="-at %f",),
        args=dict(argstr="%s",),
        disc=dict(argstr="-disc",),
        dsi=dict(argstr="-dsi",),
        environ=dict(nohash=True, usedefault=True,),
        image_orientation_vectors=dict(argstr="-iop %f",),
        input_data_prefix=dict(argstr="%s", position=0, usedefault=True,),
        input_output_type=dict(argstr="-it %s", usedefault=True,),
        invert_x=dict(argstr="-ix",),
        invert_y=dict(argstr="-iy",),
        invert_z=dict(argstr="-iz",),
        limit=dict(argstr="-limit %d",),
        mask1_file=dict(argstr="-m %s", extensions=None, mandatory=True, position=2,),
        mask1_threshold=dict(position=3,),
        mask2_file=dict(argstr="-m2 %s", extensions=None, position=4,),
        mask2_threshold=dict(position=5,),
        max=dict(extensions=None, mandatory=True,),
        out_file=dict(argstr="%s", extensions=None, position=1, usedefault=True,),
        random_seed=dict(argstr="-rseed %s",),
        runge_kutta2=dict(argstr="-rk2",),
        slice_order=dict(argstr="-sorder %d",),
        step_length=dict(argstr="-l %f",),
        swap_xy=dict(argstr="-sxy",),
        swap_yz=dict(argstr="-syz",),
        swap_zx=dict(argstr="-szx",),
        voxel_order=dict(argstr="-vorder %s",),
    )
    inputs = ODFTracker.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ODFTracker_outputs():
    output_map = dict(track_file=dict(extensions=None,),)
    outputs = ODFTracker.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..odf import ODFRecon


def test_ODFRecon_inputs():
    input_map = dict(
        DWI=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        args=dict(argstr="%s",),
        dsi=dict(argstr="-dsi",),
        environ=dict(nohash=True, usedefault=True,),
        filter=dict(argstr="-f",),
        image_orientation_vectors=dict(argstr="-iop %f",),
        matrix=dict(argstr="-mat %s", extensions=None, mandatory=True,),
        n_b0=dict(argstr="-b0 %s", mandatory=True,),
        n_directions=dict(argstr="%s", mandatory=True, position=2,),
        n_output_directions=dict(argstr="%s", mandatory=True, position=3,),
        oblique_correction=dict(argstr="-oc",),
        out_prefix=dict(argstr="%s", position=4, usedefault=True,),
        output_entropy=dict(argstr="-oe",),
        output_type=dict(argstr="-ot %s", usedefault=True,),
        sharpness=dict(argstr="-s %f",),
        subtract_background=dict(argstr="-bg",),
    )
    inputs = ODFRecon.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ODFRecon_outputs():
    output_map = dict(
        B0=dict(extensions=None,),
        DWI=dict(extensions=None,),
        ODF=dict(extensions=None,),
        entropy=dict(extensions=None,),
        max=dict(extensions=None,),
    )
    outputs = ODFRecon.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import JistBrainMp2rageDuraEstimation


def test_JistBrainMp2rageDuraEstimation_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inDistance=dict(argstr="--inDistance %f",),
        inSecond=dict(argstr="--inSecond %s", extensions=None,),
        inSkull=dict(argstr="--inSkull %s", extensions=None,),
        inoutput=dict(argstr="--inoutput %s",),
        null=dict(argstr="--null %s",),
        outDura=dict(argstr="--outDura %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = JistBrainMp2rageDuraEstimation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JistBrainMp2rageDuraEstimation_outputs():
    output_map = dict(outDura=dict(extensions=None,),)
    outputs = JistBrainMp2rageDuraEstimation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import dtiestim


def test_dtiestim_inputs():
    input_map = dict(
        B0=dict(argstr="--B0 %s", hash_files=False,),
        B0_mask_output=dict(argstr="--B0_mask_output %s", hash_files=False,),
        DTI_double=dict(argstr="--DTI_double ",),
        args=dict(argstr="%s",),
        bad_region_mask=dict(argstr="--bad_region_mask %s", extensions=None,),
        brain_mask=dict(argstr="--brain_mask %s", extensions=None,),
        correction=dict(argstr="--correction %s",),
        defaultTensor=dict(argstr="--defaultTensor %s", sep=",",),
        dwi_image=dict(argstr="--dwi_image %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        idwi=dict(argstr="--idwi %s", hash_files=False,),
        method=dict(argstr="--method %s",),
        shiftNeg=dict(argstr="--shiftNeg ",),
        shiftNegCoeff=dict(argstr="--shiftNegCoeff %f",),
        sigma=dict(argstr="--sigma %f",),
        step=dict(argstr="--step %f",),
        tensor_output=dict(argstr="--tensor_output %s", hash_files=False,),
        threshold=dict(argstr="--threshold %d",),
        verbose=dict(argstr="--verbose ",),
        weight_iterations=dict(argstr="--weight_iterations %d",),
    )
    inputs = dtiestim.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_dtiestim_outputs():
    output_map = dict(
        B0=dict(extensions=None,),
        B0_mask_output=dict(extensions=None,),
        idwi=dict(extensions=None,),
        tensor_output=dict(extensions=None,),
    )
    outputs = dtiestim.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import MultiResolutionAffineRegistration


def test_MultiResolutionAffineRegistration_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fixedImage=dict(argstr="%s", extensions=None, position=-2,),
        fixedImageMask=dict(argstr="--fixedImageMask %s", extensions=None,),
        fixedImageROI=dict(argstr="--fixedImageROI %s",),
        metricTolerance=dict(argstr="--metricTolerance %f",),
        movingImage=dict(argstr="%s", extensions=None, position=-1,),
        numIterations=dict(argstr="--numIterations %d",),
        numLineIterations=dict(argstr="--numLineIterations %d",),
        resampledImage=dict(argstr="--resampledImage %s", hash_files=False,),
        saveTransform=dict(argstr="--saveTransform %s", hash_files=False,),
        stepSize=dict(argstr="--stepSize %f",),
        stepTolerance=dict(argstr="--stepTolerance %f",),
    )
    inputs = MultiResolutionAffineRegistration.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MultiResolutionAffineRegistration_outputs():
    output_map = dict(
        resampledImage=dict(extensions=None,), saveTransform=dict(extensions=None,),
    )
    outputs = MultiResolutionAffineRegistration.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..votingbinaryholefillingimagefilter import VotingBinaryHoleFillingImageFilter


def test_VotingBinaryHoleFillingImageFilter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        background=dict(argstr="--background %d",),
        environ=dict(nohash=True, usedefault=True,),
        foreground=dict(argstr="--foreground %d",),
        inputVolume=dict(argstr="%s", extensions=None, position=-2,),
        majorityThreshold=dict(argstr="--majorityThreshold %d",),
        outputVolume=dict(argstr="%s", hash_files=False, position=-1,),
        radius=dict(argstr="--radius %s", sep=",",),
    )
    inputs = VotingBinaryHoleFillingImageFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_VotingBinaryHoleFillingImageFilter_outputs():
    output_map = dict(outputVolume=dict(extensions=None, position=-1,),)
    outputs = VotingBinaryHoleFillingImageFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Realign


def test_Realign_inputs():
    input_map = dict(
        fwhm=dict(field="eoptions.fwhm",),
        in_files=dict(copyfile=True, field="data", mandatory=True,),
        interp=dict(field="eoptions.interp",),
        jobtype=dict(usedefault=True,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        out_prefix=dict(field="roptions.prefix", usedefault=True,),
        paths=dict(),
        quality=dict(field="eoptions.quality",),
        register_to_mean=dict(field="eoptions.rtm",),
        separation=dict(field="eoptions.sep",),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        weight_img=dict(extensions=None, field="eoptions.weight",),
        wrap=dict(field="eoptions.wrap",),
        write_interp=dict(field="roptions.interp",),
        write_mask=dict(field="roptions.mask",),
        write_which=dict(field="roptions.which", maxlen=2, minlen=2, usedefault=True,),
        write_wrap=dict(field="roptions.wrap",),
    )
    inputs = Realign.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Realign_outputs():
    output_map = dict(
        mean_image=dict(extensions=None,),
        modified_in_files=dict(),
        realigned_files=dict(),
        realignment_parameters=dict(),
    )
    outputs = Realign.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import BDP


def test_BDP_inputs():
    input_map = dict(
        BVecBValPair=dict(
            argstr="--bvec %s --bval %s",
            mandatory=True,
            position=-1,
            xor=["bMatrixFile"],
        ),
        args=dict(argstr="%s",),
        bMatrixFile=dict(
            argstr="--bmat %s",
            extensions=None,
            mandatory=True,
            position=-1,
            xor=["BVecBValPair"],
        ),
        bValRatioThreshold=dict(argstr="--bval-ratio-threshold %f",),
        bfcFile=dict(
            argstr="%s",
            extensions=None,
            mandatory=True,
            position=0,
            xor=["noStructuralRegistration"],
        ),
        customDiffusionLabel=dict(
            argstr="--custom-diffusion-label %s", extensions=None,
        ),
        customLabelXML=dict(argstr="--custom-label-xml %s", extensions=None,),
        customT1Label=dict(argstr="--custom-t1-label %s", extensions=None,),
        dataSinkDelay=dict(argstr="%s",),
        dcorrRegMeasure=dict(argstr="--dcorr-reg-method %s",),
        dcorrWeight=dict(argstr="--dcorr-regularization-wt %f",),
        dwiMask=dict(argstr="--dwi-mask %s", extensions=None,),
        echoSpacing=dict(argstr="--echo-spacing=%f",),
        environ=dict(nohash=True, usedefault=True,),
        estimateODF_3DShore=dict(argstr="--3dshore --diffusion_time_ms %f",),
        estimateODF_FRACT=dict(argstr="--FRACT",),
        estimateODF_FRT=dict(argstr="--FRT",),
        estimateTensors=dict(argstr="--tensors",),
        fieldmapCorrection=dict(
            argstr="--fieldmap-correction %s",
            extensions=None,
            requires=["echoSpacing"],
        ),
        fieldmapCorrectionMethod=dict(
            argstr="--fieldmap-correction-method %s", xor=["skipIntensityCorr"],
        ),
        fieldmapSmooth=dict(argstr="--fieldmap-smooth3=%f",),
        flagConfigFile=dict(argstr="--flag-conf-file %s", extensions=None,),
        forcePartialROIStats=dict(argstr="--force-partial-roi-stats",),
        generateStats=dict(argstr="--generate-stats",),
        ignoreFieldmapFOV=dict(argstr="--ignore-fieldmap-fov",),
        ignoreMemory=dict(argstr="--ignore-memory",),
        inputDiffusionData=dict(
            argstr="--nii %s", extensions=None, mandatory=True, position=-2,
        ),
        lowMemory=dict(argstr="--low-memory",),
        noStructuralRegistration=dict(
            argstr="--no-structural-registration",
            mandatory=True,
            position=0,
            xor=["bfcFile"],
        ),
        odfLambta=dict(argstr="--odf-lambda <L>",),
        onlyStats=dict(argstr="--generate-only-stats",),
        outPrefix=dict(argstr="--output-fileprefix %s",),
        outputDiffusionCoordinates=dict(argstr="--output-diffusion-coordinate",),
        outputSubdir=dict(argstr="--output-subdir %s",),
        phaseEncodingDirection=dict(argstr="--dir=%s",),
        rigidRegMeasure=dict(argstr="--rigid-reg-measure %s",),
        skipDistortionCorr=dict(argstr="--no-distortion-correction",),
        skipIntensityCorr=dict(
            argstr="--no-intensity-correction", xor=["fieldmapCorrectionMethod"],
        ),
        skipNonuniformityCorr=dict(argstr="--no-nonuniformity-correction",),
        t1Mask=dict(argstr="--t1-mask %s", extensions=None,),
        threads=dict(argstr="--threads=%d",),
        transformDataOnly=dict(argstr="--transform-data-only",),
        transformDiffusionSurface=dict(
            argstr="--transform-diffusion-surface %s", extensions=None,
        ),
        transformDiffusionVolume=dict(
            argstr="--transform-diffusion-volume %s", extensions=None,
        ),
        transformInterpolation=dict(argstr="--transform-interpolation %s",),
        transformT1Surface=dict(argstr="--transform-t1-surface %s", extensions=None,),
        transformT1Volume=dict(argstr="--transform-t1-volume %s", extensions=None,),
    )
    inputs = BDP.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Tca


def test_Tca_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        foregroundDelta=dict(argstr="--delta %d", usedefault=True,),
        inputMaskFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        maxCorrectionSize=dict(argstr="-n %d",),
        minCorrectionSize=dict(argstr="-m %d", usedefault=True,),
        outputMaskFile=dict(argstr="-o %s", extensions=None, genfile=True,),
        timer=dict(argstr="--timer",),
        verbosity=dict(argstr="-v %d",),
    )
    inputs = Tca.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Tca_outputs():
    output_map = dict(outputMaskFile=dict(extensions=None,),)
    outputs = Tca.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..odf import MESD


def test_MESD_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bgmask=dict(argstr="-bgmask %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        fastmesd=dict(argstr="-fastmesd", requires=["mepointset"],),
        in_file=dict(
            argstr="-inputfile %s", extensions=None, mandatory=True, position=1,
        ),
        inputdatatype=dict(argstr="-inputdatatype %s",),
        inverter=dict(argstr="-filter %s", mandatory=True, position=2,),
        inverter_param=dict(argstr="%f", mandatory=True, position=3, units="NA",),
        mepointset=dict(argstr="-mepointset %d", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        scheme_file=dict(argstr="-schemefile %s", extensions=None, mandatory=True,),
    )
    inputs = MESD.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MESD_outputs():
    output_map = dict(mesd_data=dict(extensions=None,),)
    outputs = MESD.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import RegisterAVItoTalairach


def test_RegisterAVItoTalairach_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
        out_file=dict(argstr="%s", extensions=None, position=3, usedefault=True,),
        subjects_dir=dict(),
        target=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        vox2vox=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
    )
    inputs = RegisterAVItoTalairach.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegisterAVItoTalairach_outputs():
    output_map = dict(
        log_file=dict(extensions=None, usedefault=True,),
        out_file=dict(extensions=None,),
    )
    outputs = RegisterAVItoTalairach.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..label_fusion import CalcTopNCC


def test_CalcTopNCC_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-target %s", extensions=None, mandatory=True, position=1,),
        in_templates=dict(argstr="%s", mandatory=True, position=3,),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        num_templates=dict(argstr="-templates %s", mandatory=True, position=2,),
        top_templates=dict(argstr="-n %s", mandatory=True, position=4,),
    )
    inputs = CalcTopNCC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CalcTopNCC_outputs():
    output_map = dict(out_files=dict(),)
    outputs = CalcTopNCC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import UnpackSDICOMDir


def test_UnpackSDICOMDir_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        config=dict(
            argstr="-cfg %s",
            extensions=None,
            mandatory=True,
            xor=("run_info", "config", "seq_config"),
        ),
        dir_structure=dict(argstr="-%s",),
        environ=dict(nohash=True, usedefault=True,),
        log_file=dict(argstr="-log %s", extensions=None,),
        no_info_dump=dict(argstr="-noinfodump",),
        no_unpack_err=dict(argstr="-no-unpackerr",),
        output_dir=dict(argstr="-targ %s",),
        run_info=dict(
            argstr="-run %d %s %s %s",
            mandatory=True,
            xor=("run_info", "config", "seq_config"),
        ),
        scan_only=dict(argstr="-scanonly %s", extensions=None,),
        seq_config=dict(
            argstr="-seqcfg %s",
            extensions=None,
            mandatory=True,
            xor=("run_info", "config", "seq_config"),
        ),
        source_dir=dict(argstr="-src %s", mandatory=True,),
        spm_zeropad=dict(argstr="-nspmzeropad %d",),
        subjects_dir=dict(),
    )
    inputs = UnpackSDICOMDir.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import EditWMwithAseg


def test_EditWMwithAseg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        brain_file=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-4,),
        keep_in=dict(argstr="-keep-in",),
        out_file=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        seg_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        subjects_dir=dict(),
    )
    inputs = EditWMwithAseg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EditWMwithAseg_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = EditWMwithAseg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Pik


def test_Pik_inputs():
    input_map = dict(
        annotated_bar=dict(argstr="--anot_bar",),
        args=dict(argstr="%s",),
        auto_range=dict(argstr="--auto_range", xor=("image_range", "auto_range"),),
        clobber=dict(argstr="-clobber", usedefault=True,),
        depth=dict(argstr="--depth %s",),
        environ=dict(nohash=True, usedefault=True,),
        horizontal_triplanar_view=dict(
            argstr="--horizontal",
            xor=("vertical_triplanar_view", "horizontal_triplanar_view"),
        ),
        image_range=dict(
            argstr="--image_range %s %s", xor=("image_range", "auto_range"),
        ),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        jpg=dict(xor=("jpg", "png"),),
        lookup=dict(argstr="--lookup %s",),
        minc_range=dict(argstr="--range %s %s",),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            keep_extension=False,
            name_source=["input_file"],
            name_template="%s.png",
            position=-1,
        ),
        png=dict(xor=("jpg", "png"),),
        sagittal_offset=dict(argstr="--sagittal_offset %s",),
        sagittal_offset_perc=dict(argstr="--sagittal_offset_perc %d",),
        scale=dict(argstr="--scale %s", usedefault=True,),
        slice_x=dict(argstr="-x", xor=("slice_z", "slice_y", "slice_x"),),
        slice_y=dict(argstr="-y", xor=("slice_z", "slice_y", "slice_x"),),
        slice_z=dict(argstr="-z", xor=("slice_z", "slice_y", "slice_x"),),
        start=dict(argstr="--slice %s",),
        tile_size=dict(argstr="--tilesize %s",),
        title=dict(argstr="%s",),
        title_size=dict(argstr="--title_size %s", requires=["title"],),
        triplanar=dict(argstr="--triplanar",),
        vertical_triplanar_view=dict(
            argstr="--vertical",
            xor=("vertical_triplanar_view", "horizontal_triplanar_view"),
        ),
        width=dict(argstr="--width %s",),
    )
    inputs = Pik.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Pik_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = Pik.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..longitudinal import FuseSegmentations


def test_FuseSegmentations_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_norms=dict(argstr="-n %s", mandatory=True,),
        in_segmentations=dict(argstr="-a %s", mandatory=True,),
        in_segmentations_noCC=dict(argstr="-c %s", mandatory=True,),
        out_file=dict(extensions=None, mandatory=True, position=-1,),
        subject_id=dict(argstr="%s", position=-3,),
        subjects_dir=dict(),
        timepoints=dict(argstr="%s", mandatory=True, position=-2,),
    )
    inputs = FuseSegmentations.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FuseSegmentations_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = FuseSegmentations.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import CreateJacobianDeterminantImage


def test_CreateJacobianDeterminantImage_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        deformationField=dict(
            argstr="%s", extensions=None, mandatory=True, position=1,
        ),
        doLogJacobian=dict(argstr="%d", position=3,),
        environ=dict(nohash=True, usedefault=True,),
        imageDimension=dict(argstr="%d", mandatory=True, position=0,),
        num_threads=dict(nohash=True, usedefault=True,),
        outputImage=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        useGeometric=dict(argstr="%d", position=4,),
    )
    inputs = CreateJacobianDeterminantImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CreateJacobianDeterminantImage_outputs():
    output_map = dict(jacobian_image=dict(extensions=None,),)
    outputs = CreateJacobianDeterminantImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Pialmesh


def test_Pialmesh_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        exportPrefix=dict(argstr="--prefix %s",),
        inputMaskFile=dict(argstr="-m %s", extensions=None, mandatory=True,),
        inputSurfaceFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        inputTissueFractionFile=dict(argstr="-f %s", extensions=None, mandatory=True,),
        laplacianSmoothing=dict(argstr="--smooth %f", usedefault=True,),
        maxThickness=dict(argstr="--max %f", usedefault=True,),
        normalSmoother=dict(argstr="--nc %f", usedefault=True,),
        numIterations=dict(argstr="-n %d", usedefault=True,),
        outputInterval=dict(argstr="--interval %d", usedefault=True,),
        outputSurfaceFile=dict(argstr="-o %s", extensions=None, genfile=True,),
        recomputeNormals=dict(argstr="--norm",),
        searchRadius=dict(argstr="-r %f", usedefault=True,),
        stepSize=dict(argstr="-s %f", usedefault=True,),
        tangentSmoother=dict(argstr="--tc %f",),
        timer=dict(argstr="--timer",),
        tissueThreshold=dict(argstr="-t %f", usedefault=True,),
        verbosity=dict(argstr="-v %d",),
    )
    inputs = Pialmesh.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Pialmesh_outputs():
    output_map = dict(outputSurfaceFile=dict(extensions=None,),)
    outputs = Pialmesh.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import TProject


def test_TProject_inputs():
    input_map = dict(
        TR=dict(argstr="-TR %g",),
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask", xor=["mask"],),
        bandpass=dict(argstr="-bandpass %g %g",),
        blur=dict(argstr="-blur %g",),
        cenmode=dict(argstr="-cenmode %s",),
        censor=dict(argstr="-censor %s", extensions=None,),
        censortr=dict(argstr="-CENSORTR %s",),
        concat=dict(argstr="-concat %s", extensions=None,),
        dsort=dict(argstr="-dsort %s...",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=1,
        ),
        mask=dict(argstr="-mask %s", extensions=None,),
        noblock=dict(argstr="-noblock",),
        norm=dict(argstr="-norm",),
        num_threads=dict(nohash=True, usedefault=True,),
        ort=dict(argstr="-ort %s", extensions=None,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_tproject",
            position=-1,
        ),
        outputtype=dict(),
        polort=dict(argstr="-polort %d",),
        stopband=dict(argstr="-stopband %g %g",),
    )
    inputs = TProject.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TProject_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = TProject.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import SurfaceSmooth


def test_SurfaceSmooth_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cortex=dict(argstr="--cortex", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        fwhm=dict(argstr="--fwhm %.4f", xor=["smooth_iters"],),
        hemi=dict(argstr="--hemi %s", mandatory=True,),
        in_file=dict(argstr="--sval %s", extensions=None, mandatory=True,),
        out_file=dict(argstr="--tval %s", extensions=None, genfile=True,),
        reshape=dict(argstr="--reshape",),
        smooth_iters=dict(argstr="--smooth %d", xor=["fwhm"],),
        subject_id=dict(argstr="--s %s", mandatory=True,),
        subjects_dir=dict(),
    )
    inputs = SurfaceSmooth.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SurfaceSmooth_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = SurfaceSmooth.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import DARTELNorm2MNI


def test_DARTELNorm2MNI_inputs():
    input_map = dict(
        apply_to_files=dict(
            copyfile=False, field="mni_norm.data.subjs.images", mandatory=True,
        ),
        bounding_box=dict(field="mni_norm.bb",),
        flowfield_files=dict(field="mni_norm.data.subjs.flowfields", mandatory=True,),
        fwhm=dict(field="mni_norm.fwhm",),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        modulate=dict(field="mni_norm.preserve",),
        paths=dict(),
        template_file=dict(
            copyfile=False,
            extensions=[".hdr", ".img", ".img.gz", ".nii"],
            field="mni_norm.template",
            mandatory=True,
        ),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        voxel_size=dict(field="mni_norm.vox",),
    )
    inputs = DARTELNorm2MNI.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DARTELNorm2MNI_outputs():
    output_map = dict(
        normalization_parameter_file=dict(extensions=None,), normalized_files=dict(),
    )
    outputs = DARTELNorm2MNI.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MRIsConvert


def test_MRIsConvert_inputs():
    input_map = dict(
        annot_file=dict(argstr="--annot %s", extensions=None,),
        args=dict(argstr="%s",),
        dataarray_num=dict(argstr="--da_num %d",),
        environ=dict(nohash=True, usedefault=True,),
        functional_file=dict(argstr="-f %s", extensions=None,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        label_file=dict(argstr="--label %s", extensions=None,),
        labelstats_outfile=dict(argstr="--labelstats %s", extensions=None,),
        normal=dict(argstr="-n",),
        origname=dict(argstr="-o %s",),
        out_datatype=dict(mandatory=True, xor=["out_file"],),
        out_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            mandatory=True,
            position=-1,
            xor=["out_datatype"],
        ),
        parcstats_file=dict(argstr="--parcstats %s", extensions=None,),
        patch=dict(argstr="-p",),
        rescale=dict(argstr="-r",),
        scalarcurv_file=dict(argstr="-c %s", extensions=None,),
        scale=dict(argstr="-s %.3f",),
        subjects_dir=dict(),
        talairachxfm_subjid=dict(argstr="-t %s",),
        to_scanner=dict(argstr="--to-scanner",),
        to_tkr=dict(argstr="--to-tkr",),
        vertex=dict(argstr="-v",),
        xyz_ascii=dict(argstr="-a",),
    )
    inputs = MRIsConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRIsConvert_outputs():
    output_map = dict(converted=dict(extensions=None,),)
    outputs = MRIsConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MakeSurfaces


def test_MakeSurfaces_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        copy_inputs=dict(),
        environ=dict(nohash=True, usedefault=True,),
        fix_mtl=dict(argstr="-fix_mtl",),
        hemisphere=dict(argstr="%s", mandatory=True, position=-1,),
        in_T1=dict(argstr="-T1 %s", extensions=None,),
        in_aseg=dict(argstr="-aseg %s", extensions=None,),
        in_filled=dict(extensions=None, mandatory=True,),
        in_label=dict(extensions=None, xor=["noaparc"],),
        in_orig=dict(argstr="-orig %s", extensions=None, mandatory=True,),
        in_white=dict(extensions=None,),
        in_wm=dict(extensions=None, mandatory=True,),
        longitudinal=dict(argstr="-long",),
        maximum=dict(argstr="-max %.1f",),
        mgz=dict(argstr="-mgz",),
        no_white=dict(argstr="-nowhite",),
        noaparc=dict(argstr="-noaparc", xor=["in_label"],),
        orig_pial=dict(argstr="-orig_pial %s", extensions=None, requires=["in_label"],),
        orig_white=dict(argstr="-orig_white %s", extensions=None,),
        subject_id=dict(argstr="%s", mandatory=True, position=-2, usedefault=True,),
        subjects_dir=dict(),
        white=dict(argstr="-white %s",),
        white_only=dict(argstr="-whiteonly",),
    )
    inputs = MakeSurfaces.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MakeSurfaces_outputs():
    output_map = dict(
        out_area=dict(extensions=None,),
        out_cortex=dict(extensions=None,),
        out_curv=dict(extensions=None,),
        out_pial=dict(extensions=None,),
        out_thickness=dict(extensions=None,),
        out_white=dict(extensions=None,),
    )
    outputs = MakeSurfaces.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import FitMSParams


def test_FitMSParams_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        flip_list=dict(),
        in_files=dict(argstr="%s", mandatory=True, position=-2,),
        out_dir=dict(argstr="%s", genfile=True, position=-1,),
        subjects_dir=dict(),
        te_list=dict(),
        tr_list=dict(),
        xfm_list=dict(),
    )
    inputs = FitMSParams.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FitMSParams_outputs():
    output_map = dict(
        pd_image=dict(extensions=None,),
        t1_image=dict(extensions=None,),
        t2star_image=dict(extensions=None,),
    )
    outputs = FitMSParams.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Bandpass


def test_Bandpass_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask",),
        blur=dict(argstr="-blur %f",),
        despike=dict(argstr="-despike",),
        environ=dict(nohash=True, usedefault=True,),
        highpass=dict(argstr="%f", mandatory=True, position=-3,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        localPV=dict(argstr="-localPV %f",),
        lowpass=dict(argstr="%f", mandatory=True, position=-2,),
        mask=dict(argstr="-mask %s", extensions=None, position=2,),
        nfft=dict(argstr="-nfft %d",),
        no_detrend=dict(argstr="-nodetrend",),
        normalize=dict(argstr="-norm",),
        notrans=dict(argstr="-notrans",),
        num_threads=dict(nohash=True, usedefault=True,),
        orthogonalize_dset=dict(argstr="-dsort %s", extensions=None,),
        orthogonalize_file=dict(argstr="-ort %s",),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_bp",
            position=1,
        ),
        outputtype=dict(),
        tr=dict(argstr="-dt %f",),
    )
    inputs = Bandpass.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Bandpass_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Bandpass.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DTIFit


def test_DTIFit_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bgmask=dict(argstr="-bgmask %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        non_linear=dict(argstr="-nonlinear", position=3,),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        scheme_file=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
    )
    inputs = DTIFit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DTIFit_outputs():
    output_map = dict(tensor_fitted=dict(extensions=None,),)
    outputs = DTIFit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import ESLR


def test_ESLR_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        closingSize=dict(argstr="--closingSize %d",),
        environ=dict(nohash=True, usedefault=True,),
        high=dict(argstr="--high %d",),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        low=dict(argstr="--low %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        openingSize=dict(argstr="--openingSize %d",),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        preserveOutside=dict(argstr="--preserveOutside ",),
        safetySize=dict(argstr="--safetySize %d",),
    )
    inputs = ESLR.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ESLR_outputs():
    output_map = dict(outputVolume=dict(extensions=None,),)
    outputs = ESLR.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import DicomImport


def test_DicomImport_inputs():
    input_map = dict(
        format=dict(field="convopts.format", usedefault=True,),
        icedims=dict(field="convopts.icedims", usedefault=True,),
        in_files=dict(field="data", mandatory=True,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        output_dir=dict(field="outdir", usedefault=True,),
        output_dir_struct=dict(field="root", usedefault=True,),
        paths=dict(),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
    )
    inputs = DicomImport.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DicomImport_outputs():
    output_map = dict(out_files=dict(),)
    outputs = DicomImport.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MultiplyImages


def test_MultiplyImages_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="%d", mandatory=True, position=0,),
        environ=dict(nohash=True, usedefault=True,),
        first_input=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        num_threads=dict(nohash=True, usedefault=True,),
        output_product_image=dict(
            argstr="%s", extensions=None, mandatory=True, position=3,
        ),
        second_input=dict(argstr="%s", mandatory=True, position=2,),
    )
    inputs = MultiplyImages.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MultiplyImages_outputs():
    output_map = dict(output_product_image=dict(extensions=None,),)
    outputs = MultiplyImages.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Retroicor


def test_Retroicor_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        card=dict(argstr="-card %s", extensions=None, position=-2,),
        cardphase=dict(
            argstr="-cardphase %s", extensions=None, hash_files=False, position=-6,
        ),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        num_threads=dict(nohash=True, usedefault=True,),
        order=dict(argstr="-order %s", position=-5,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_retroicor",
            position=1,
        ),
        outputtype=dict(),
        resp=dict(argstr="-resp %s", extensions=None, position=-3,),
        respphase=dict(
            argstr="-respphase %s", extensions=None, hash_files=False, position=-7,
        ),
        threshold=dict(argstr="-threshold %d", position=-4,),
    )
    inputs = Retroicor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Retroicor_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Retroicor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import FSL2Scheme


def test_FSL2Scheme_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bscale=dict(argstr="-bscale %d", units="NA",),
        bval_file=dict(
            argstr="-bvalfile %s", extensions=None, mandatory=True, position=2,
        ),
        bvec_file=dict(
            argstr="-bvecfile %s", extensions=None, mandatory=True, position=1,
        ),
        diffusiontime=dict(argstr="-diffusiontime %f", units="NA",),
        environ=dict(nohash=True, usedefault=True,),
        flipx=dict(argstr="-flipx",),
        flipy=dict(argstr="-flipy",),
        flipz=dict(argstr="-flipz",),
        interleave=dict(argstr="-interleave",),
        numscans=dict(argstr="-numscans %d", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        usegradmod=dict(argstr="-usegradmod",),
    )
    inputs = FSL2Scheme.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FSL2Scheme_outputs():
    output_map = dict(scheme=dict(extensions=None,),)
    outputs = FSL2Scheme.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import MedicAlgorithmLesionToads


def test_MedicAlgorithmLesionToads_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inAtlas=dict(argstr="--inAtlas %s",),
        inAtlas2=dict(argstr="--inAtlas2 %s", extensions=None,),
        inAtlas3=dict(argstr="--inAtlas3 %s", extensions=None,),
        inAtlas4=dict(argstr="--inAtlas4 %s", extensions=None,),
        inAtlas5=dict(argstr="--inAtlas5 %f",),
        inAtlas6=dict(argstr="--inAtlas6 %s",),
        inConnectivity=dict(argstr="--inConnectivity %s",),
        inCorrect=dict(argstr="--inCorrect %s",),
        inFLAIR=dict(argstr="--inFLAIR %s", extensions=None,),
        inInclude=dict(argstr="--inInclude %s",),
        inMaximum=dict(argstr="--inMaximum %d",),
        inMaximum2=dict(argstr="--inMaximum2 %d",),
        inMaximum3=dict(argstr="--inMaximum3 %d",),
        inMaximum4=dict(argstr="--inMaximum4 %f",),
        inMaximum5=dict(argstr="--inMaximum5 %d",),
        inOutput=dict(argstr="--inOutput %s",),
        inOutput2=dict(argstr="--inOutput2 %s",),
        inOutput3=dict(argstr="--inOutput3 %s",),
        inSmooting=dict(argstr="--inSmooting %f",),
        inT1_MPRAGE=dict(argstr="--inT1_MPRAGE %s", extensions=None,),
        inT1_SPGR=dict(argstr="--inT1_SPGR %s", extensions=None,),
        null=dict(argstr="--null %s",),
        outCortical=dict(argstr="--outCortical %s", hash_files=False,),
        outFilled=dict(argstr="--outFilled %s", hash_files=False,),
        outHard=dict(argstr="--outHard %s", hash_files=False,),
        outHard2=dict(argstr="--outHard2 %s", hash_files=False,),
        outInhomogeneity=dict(argstr="--outInhomogeneity %s", hash_files=False,),
        outLesion=dict(argstr="--outLesion %s", hash_files=False,),
        outMembership=dict(argstr="--outMembership %s", hash_files=False,),
        outSulcal=dict(argstr="--outSulcal %s", hash_files=False,),
        outWM=dict(argstr="--outWM %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = MedicAlgorithmLesionToads.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MedicAlgorithmLesionToads_outputs():
    output_map = dict(
        outCortical=dict(extensions=None,),
        outFilled=dict(extensions=None,),
        outHard=dict(extensions=None,),
        outHard2=dict(extensions=None,),
        outInhomogeneity=dict(extensions=None,),
        outLesion=dict(extensions=None,),
        outMembership=dict(extensions=None,),
        outSulcal=dict(extensions=None,),
        outWM=dict(extensions=None,),
    )
    outputs = MedicAlgorithmLesionToads.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ResampleImageBySpacing


def test_ResampleImageBySpacing_inputs():
    input_map = dict(
        addvox=dict(argstr="%d", position=6, requires=["apply_smoothing"],),
        apply_smoothing=dict(argstr="%d", position=5,),
        args=dict(argstr="%s",),
        dimension=dict(argstr="%d", position=1, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        input_image=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        nn_interp=dict(argstr="%d", position=-1, requires=["addvox"],),
        num_threads=dict(nohash=True, usedefault=True,),
        out_spacing=dict(argstr="%s", mandatory=True, position=4,),
        output_image=dict(
            argstr="%s",
            extensions=None,
            keep_extension=True,
            name_source=["input_image"],
            name_template="%s_resampled",
            position=3,
        ),
    )
    inputs = ResampleImageBySpacing.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ResampleImageBySpacing_outputs():
    output_map = dict(output_image=dict(extensions=None,),)
    outputs = ResampleImageBySpacing.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import RegistrationSynQuick


def test_RegistrationSynQuick_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="-d %d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        fixed_image=dict(argstr="-f %s...", mandatory=True,),
        histogram_bins=dict(argstr="-r %d", usedefault=True,),
        moving_image=dict(argstr="-m %s...", mandatory=True,),
        num_threads=dict(argstr="-n %d", usedefault=True,),
        output_prefix=dict(argstr="-o %s", usedefault=True,),
        precision_type=dict(argstr="-p %s", usedefault=True,),
        spline_distance=dict(argstr="-s %d", usedefault=True,),
        transform_type=dict(argstr="-t %s", usedefault=True,),
        use_histogram_matching=dict(argstr="-j %d",),
    )
    inputs = RegistrationSynQuick.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegistrationSynQuick_outputs():
    output_map = dict(
        forward_warp_field=dict(extensions=None,),
        inverse_warp_field=dict(extensions=None,),
        inverse_warped_image=dict(extensions=None,),
        out_matrix=dict(extensions=None,),
        warped_image=dict(extensions=None,),
    )
    outputs = RegistrationSynQuick.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
